@@ -48,24 +48,6 @@
 #define min(a, b) (((a) < (b)) ? (a) : (b))
 #define MEMBER_SIZE(S, M) sizeof(((S *)0)->M)
 
-/* function pointers */
-
-int (*test_runner_main)(int, char**);
-int (*xstat)(const char *, struct stat *);
-int (*xkillpg)(pid_t, int);
-int (*xexecvp)(const char *, char *const []);
-pid_t (*xwaitpid)(pid_t, int *, int);
-pid_t (*xfork)();
-int (*xkevent)(int, const struct kevent *, int, struct kevent *, int , const
-    struct timespec *);
-int (*xopen)(const char *path, int flags, ...);
-char * (*xrealpath)(const char *, char *);
-void (*xfree)(void *);
-void (*xwarnx)(const char *, ...);
-void (*xerrx)(int, const char *, ...);
-int (*xlist_dir)(char *);
-int (*xtcsetattr)(int fd, int action, const struct termios *tp);
-
 /* globals */
 
 extern int optind;
@@ -118,24 +100,6 @@ main(int argc, char *argv[]) {
 	struct kevent evSet;
 	unsigned open_max;
 
-	if ((*test_runner_main))
-		return(test_runner_main(argc, argv));
-
-	/* set up pointers to real functions */
-	xstat = stat;
-	xkevent = kevent;
-	xkillpg = killpg;
-	xexecvp = execvp;
-	xwaitpid = waitpid;
-	xfork = fork;
-	xopen = open;
-	xrealpath = realpath;
-	xfree = free;
-	xwarnx = warnx;
-	xerrx = errx;
-	xlist_dir = list_dir;
-	xtcsetattr = tcsetattr;
-
 	 if (pledge("stdio rpath tty proc exec", NULL) == -1)
 	    err(1, "pledge");
 
@@ -197,6 +161,9 @@ main(int argc, char *argv[]) {
 	if ((kq = kqueue()) == -1)
 		err(1, "cannot create kqueue");
 
+	if (fcntl(kq, F_SETFD, FD_CLOEXEC) == -1)
+		warn("failed to set FD_CLOEXEC to kqueue descriptor");
+
 	/* expect file list from a pipe */
 	if (isatty(fileno(stdin)))
 		usage();
@@ -214,10 +181,10 @@ main(int argc, char *argv[]) {
 
 	if (!noninteractive_opt) {
 		/* Attempt to open a tty so that editors don't complain */
-		ttyfd = xopen(_PATH_TTY, O_RDONLY);
+		ttyfd = open(_PATH_TTY, O_RDONLY);
 		if (ttyfd > STDIN_FILENO) {
 			if (dup2(ttyfd, STDIN_FILENO) != 0)
-				xwarnx("can't dup2 to stdin");
+				warnx("can't dup2 to stdin");
 			close(ttyfd);
 		}
 
@@ -227,8 +194,8 @@ main(int argc, char *argv[]) {
 
 		/* Use keyboard input as a trigger */
 		EV_SET(&evSet, STDIN_FILENO, EVFILT_READ, EV_ADD, NOTE_LOWAT, 1, NULL);
-		if (xkevent(kq, &evSet, 1, NULL, 0, NULL) == -1)
-			xwarnx("failed to register stdin");
+		if (kevent(kq, &evSet, 1, NULL, 0, NULL) == -1)
+			warnx("failed to register stdin");
 	}
 
 	watch_loop(kq, argv+argv_index);
@@ -251,8 +218,8 @@ terminate_utility() {
 	terminating = 1;
 
 	if (child_pid > 0) {
-		xkillpg(child_pid, SIGTERM);
-		xwaitpid(child_pid, &status, 0);
+		killpg(child_pid, SIGTERM);
+		waitpid(child_pid, &status, 0);
 		child_pid = 0;
 	}
 
@@ -264,7 +231,7 @@ terminate_utility() {
 void
 handle_exit(int sig) {
 	if ((!noninteractive_opt) && (termios_set))
-		xtcsetattr(STDIN_FILENO, TCSADRAIN, &canonical_tty);
+		tcsetattr(STDIN_FILENO, TCSADRAIN, &canonical_tty);
 
 	terminate_utility();
 
@@ -279,7 +246,7 @@ proc_exit(int sig) {
 	int status;
 
 	if ((!noninteractive_opt) && (termios_set))
-		xtcsetattr(STDIN_FILENO, TCSADRAIN, &canonical_tty);
+		tcsetattr(STDIN_FILENO, TCSADRAIN, &canonical_tty);
 
 	if (wait(&status) != -1)
 		child_status = status;
@@ -323,8 +290,8 @@ process_input(FILE *file, WatchFile *files[], int max_files) {
 		if (buf[0] == '\0')
 			continue;
 
-		if (xstat(buf, &sb) == -1) {
-			xwarnx("unable to stat '%s'", buf);
+		if (stat(buf, &sb) == -1) {
+			warnx("unable to stat '%s'", buf);
 			continue;
 		}
 		if (S_ISREG(sb.st_mode) != 0) {
@@ -350,7 +317,7 @@ process_input(FILE *file, WatchFile *files[], int max_files) {
 				strlcpy(files[n_files]->fn, path,
 				    MEMBER_SIZE(WatchFile, fn));
 				files[n_files]->is_dir = 1;
-				files[n_files]->file_count = xlist_dir(path);
+				files[n_files]->file_count = list_dir(path);
 				files[n_files]->mode = sb.st_mode;
 				files[n_files]->ino = sb.st_ino;
 				n_files++;
@@ -420,7 +387,7 @@ set_options(char *argv[]) {
 	if (argv[optind] == 0)
 		usage();
 	if ((shell_opt == 1) && (argv[optind+1] != 0))
-		xerrx(1, "-s requires commands to be formatted as a single argument");
+		errx(1, "-s requires commands to be formatted as a single argument");
 	return optind;
 }
 
@@ -437,22 +404,16 @@ run_utility(char *argv[]) {
 	char **new_argv;
 	char *p, *arg_buf;
 	int argc;
-	int stdin_pipe[2] = {0, 0};
 
-	if (restart_opt == 1) {
+	if (restart_opt == 1)
 		terminate_utility();
 
-		if (pipe(stdin_pipe) != 0)
-			err(1, "Failed to create stdin pipe");
-		close(stdin_pipe[1]);
-	}
-
 	if (shell_opt == 1) {
 		/* run argv[1] with a shell using the leading edge as $0 */
 		argc = 4;
 		arg_buf = malloc(ARG_MAX);
 		new_argv = calloc(argc+1, sizeof(char *));
-		xrealpath(leading_edge->fn, arg_buf);
+		realpath(leading_edge->fn, arg_buf);
 		new_argv[0] = getenv("SHELL");
 		new_argv[1] = "-c";
 		new_argv[2] = argv[0];
@@ -468,7 +429,7 @@ run_utility(char *argv[]) {
 		for (m=0, i=0, p=arg_buf; i<argc; i++) {
 			new_argv[i] = p;
 			if ((m < 1) && (strcmp(argv[i], "/_")) == 0) {
-				p += strlen(xrealpath(leading_edge->fn, p));
+				p += strlen(realpath(leading_edge->fn, p));
 				m++;
 			}
 			else
@@ -477,7 +438,7 @@ run_utility(char *argv[]) {
 		}
 	}
 
-	pid = xfork();
+	pid = fork();
 	if (pid == -1)
 		err(1, "can't fork");
 
@@ -495,11 +456,12 @@ run_utility(char *argv[]) {
 		/* Set process group so subprocess can be signaled */
 		if (restart_opt == 1) {
 			setpgid(0, getpid());
-			dup2(stdin_pipe[0], STDIN_FILENO);
+			close(STDIN_FILENO);
+			open(_PATH_DEVNULL, O_RDONLY);
 		}
 		/* wait up to 1 seconds for each file to become available */
 		for (i=0; i < 10; i++) {
-			ret = xexecvp(new_argv[0], new_argv);
+			ret = execvp(new_argv[0], new_argv);
 			if (errno == ETXTBSY)
 				nanosleep(&delay, NULL);
 			else break;
@@ -517,8 +479,8 @@ run_utility(char *argv[]) {
 			print_child_status(child_status);
 	}
 
-	xfree(arg_buf);
-	xfree(new_argv);
+	free(arg_buf);
+	free(new_argv);
 }
 
 /*
@@ -533,9 +495,9 @@ watch_file(int kq, WatchFile *file) {
 	/* wait up to 1 second for file to become available */
 	for (i=0; i < 10; i++) {
 		#ifdef O_EVTONLY
-		file->fd = xopen(file->fn, O_RDONLY|O_EVTONLY);
+		file->fd = open(file->fn, O_RDONLY|O_CLOEXEC|O_EVTONLY);
 		#else
-		file->fd = xopen(file->fn, O_RDONLY);
+		file->fd = open(file->fn, O_RDONLY|O_CLOEXEC);
 		#endif
 		if (file->fd == -1) nanosleep(&delay, NULL);
 		else break;
@@ -548,7 +510,7 @@ watch_file(int kq, WatchFile *file) {
 
 	EV_SET(&evSet, file->fd, EVFILT_VNODE, EV_ADD | EV_CLEAR, NOTE_ALL, 0,
 	    file);
-	if (xkevent(kq, &evSet, 1, NULL, 0, NULL) == -1) {
+	if (kevent(kq, &evSet, 1, NULL, 0, NULL) == -1) {
 		if (errno == ENOSPC)
 			errx(1, "Unable to allocate memory for kernel queue."
 			    " Please consult"
@@ -568,7 +530,7 @@ compare_dir_contents(WatchFile *file) {
 
 	/* wait up to 0.5 seconds for file to become available */
 	for (i=0; i < 5; i++) {
-		if (xlist_dir(file->fn) == file->file_count)
+		if (list_dir(file->fn) == file->file_count)
 			return 0;
 		nanosleep(&delay, NULL);
 	}
@@ -617,15 +579,15 @@ watch_loop(int kq, char *argv[]) {
 
 main:
 	if (!noninteractive_opt) {
-		xtcsetattr(STDIN_FILENO, TCSADRAIN, &character_tty);
+		tcsetattr(STDIN_FILENO, TCSADRAIN, &character_tty);
 		termios_set = 1;
 	}
 
 	if ((reopen_only == 1) || (collate_only == 1)) {
-		nev = xkevent(kq, NULL, 0, evList, 32, &evTimeout);
+		nev = kevent(kq, NULL, 0, evList, 32, &evTimeout);
 	}
 	else {
-		nev = xkevent(kq, NULL, 0, evList, 32, NULL);
+		nev = kevent(kq, NULL, 0, evList, 32, NULL);
 		dir_modified = 0;
 	}
 
@@ -641,7 +603,7 @@ main:
 			if (read(STDIN_FILENO, &c, 1) < 1) {
 				EV_SET(&evSet, STDIN_FILENO, EVFILT_READ,
 				    EV_DELETE, NOTE_LOWAT, 0, NULL);
-				if (xkevent(kq, &evSet, 1, NULL, 0, NULL) == -1)
+				if (kevent(kq, &evSet, 1, NULL, 0, NULL) == -1)
 					err(1, "failed to remove READ event");
 			}
 			else {
@@ -659,7 +621,7 @@ main:
 			dir_modified += compare_dir_contents(file);
 	}
 	if (!noninteractive_opt)
-		xtcsetattr(STDIN_FILENO, TCSADRAIN, &canonical_tty);
+		tcsetattr(STDIN_FILENO, TCSADRAIN, &canonical_tty);
 
 	collate_only = 0;
 	for (i=0; i<nev; i++) {
@@ -670,7 +632,7 @@ main:
 		    evList[i].fflags & NOTE_RENAME) {
 			EV_SET(&evSet, file->fd, EVFILT_VNODE, EV_DELETE,
 			    NOTE_ALL, 0, file);
-			if (xkevent(kq, &evSet, 1, NULL, 0, NULL) == -1)
+			if (kevent(kq, &evSet, 1, NULL, 0, NULL) == -1)
 				err(1, "failed to remove VNODE event");
 #if !defined(_LINUX_PORT)
 			/* free file descriptor no longer monitored by kqueue */
@@ -704,15 +666,16 @@ main:
 		}
 
 		if (evList[i].fflags & NOTE_ATTRIB &&
-		    S_ISREG(file->mode) != 0 && xstat(file->fn, &sb) == 0) {
+		    S_ISREG(file->mode) != 0 && stat(file->fn, &sb) == 0) {
 			if (file->mode != sb.st_mode) {
 			    do_exec = 1;
 			    file->mode = sb.st_mode;
 			}
-			/* Possible on Linux when a running binary is unlinked */
 			if (file->ino != sb.st_ino) {
-			    do_exec = 1;
-			    file->ino = sb.st_ino;
+#if defined(_LINUX_PORT)
+				do_exec = 1;
+#endif
+				file->ino = sb.st_ino;
 			}
 		}
 		else if (evList[i].fflags & NOTE_ATTRIB)
@@ -746,7 +709,7 @@ main:
 	}
 	if (dir_modified > 0) {
 		terminate_utility();
-		xerrx(2, "directory altered");
+		errx(2, "directory altered");
 	}
 
 	goto main;
